@@ -40,16 +40,6 @@ tidy.predictions <- tidy.comparisons
 tidy.hypotheses <- tidy.comparisons
 
 
-#' tidy helper
-#'
-#' @noRd
-#' @export
-tidy.marginalmeans <- function(x, ...) {
-  insight::check_if_installed("tibble")
-  tibble::as_tibble(x)
-}
-
-
 #' @noRd
 #' @export
 glance.slopes <- function(x, ...) {
@@ -92,8 +82,3 @@ glance.comparisons <- glance.slopes
 #' @export
 glance.hypotheses <- glance.slopes
 
-
-#' @noRd
-#' @export
-glance.marginalmeans <- glance.slopes
-
