@@ -20,15 +20,21 @@ sanitize_type <- function(model, type, by = FALSE, calling_function = "raw") {
         cl <- class(model)[1]
     }
 
-    if (!cl %in% type_dictionary$class) {
-        cl <- "other"
-    }
+    # if (!cl %in% type_dictionary$class) {
+    #     cl <- "other"
+    # }
 
     dict <- type_dictionary
     # raw is often invoked by `get_predict()`, which is required for {clarify} and others.
     # we only allow invlink(link) in predictions() and marginal_means(), which are handled by {marginaleffects}
-    
-    if (!calling_function %in% "predictions") {# || !isFALSE(by)) {
+
+    # invlink(link) only supported by predictions()
+    if (!isTRUE(calling_function %in% "predictions")) {
+        dict <- dict[dict$type != "invlink(link)", , drop = FALSE]
+    }
+
+    # invlink(link) only default for predictions() if by=FALSE
+    if (!isTRUE(type == "invlink(link)") && !isFALSE(by)) {
         dict <- dict[dict$type != "invlink(link)", , drop = FALSE]
     }
 
@@ -40,10 +46,14 @@ sanitize_type <- function(model, type, by = FALSE, calling_function = "raw") {
     }
 
     dict <- dict[dict$class == cl, , drop = FALSE]
-    checkmate::assert_choice(type, choices = dict$type, null.ok = TRUE)
-    if (is.null(type)) {
-        type <- dict$type[1]
+    if (nrow(dict) > 0) {
+        checkmate::assert_choice(type, choices = dict$type, null.ok = TRUE)
+        if (is.null(type)) {
+            type <- dict$type[1]
+        }
     }
 
+    if (is.null(type)) type <- "response"
+
     return(type)
-}
\ No newline at end of file
+}
